#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import domain, tech, tech

from ..graphql.input.edit_tech_input import EditTechInput
from ..graphql.input.add_tech_input import AddTechInput
from ..graphql.mutation.add_tech import addTech
from ..graphql.mutation.edit_tech import editTech
from ..graphql.mutation.remove_tech import removeTech
from ..graphql.query.techs import techs
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_tech(
    client: SymphonyClient, name: str, domainId: str
) -> tech:
   
    tech_input = AddTechInput(name=name, domainFk=domainId)
    result = addTech.execute(client, input=tech_input)
    return tech(name=result.name, id=result.id, domainFK=result.domainFk)


def edit_tech(
    client: SymphonyClient,
    tech: tech,
    new_name: Optional[str] = None,
    domainId: domain = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editTech.execute(client, input=EditTechInput(id=tech.id, name=new_name, domainFk=domainId))







#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import CounterFamiliy

from ..graphql.input.edit_counter_family_input import EditCounterFamilyInput
from ..graphql.input.add_counter_family_input import AddCounterFamilyInput
from ..graphql.mutation.add_counter_family import addCounterFamily
from ..graphql.mutation.edit_counter_family import editCounterFamily
from ..graphql.mutation.remove_counter_family import removeCounterFamily
from ..graphql.query.counter_families import counterFamilies
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_counter_family(
    client: SymphonyClient, name: str
) -> CounterFamiliy:
   
    counter_family_input = AddCounterFamilyInput(name=name)
    result = addCounterFamily.execute(client, input=counter_family_input)
    return CounterFamiliy(name=result.name, id=result.id)

def edit_counter_family(
    client: SymphonyClient,
    counter_family: CounterFamiliy,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editCounterFamily.execute(client, input=EditCounterFamilyInput(id=counter_family.id, name=new_name))



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from ...config import custom_scalars, datetime
from gql_client.runtime.variables import encode_variables
from gql import gql, Client
from gql.transport.exceptions import TransportQueryError
from functools import partial
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional
from time import perf_counter
from dataclasses_json import DataClassJsonMixin, config

from ..fragment.customer import CustomerFragment, QUERY as CustomerFragmentQuery


# fmt: off
QUERY: List[str] = CustomerFragmentQuery + ["""
query ServiceTypeServicesQuery($id: ID!) {
  serviceType: node(id: $id) {
    ... on ServiceType {
      services {
        id
        name
        externalId
        customer {
          ...CustomerFragment
        }
      }
    }
  }
}

"""
]


class ServiceTypeServicesQuery:
    @dataclass(frozen=True)
    class ServiceTypeServicesQueryData(DataClassJsonMixin):
        @dataclass(frozen=True)
        class Node(DataClassJsonMixin):
            @dataclass(frozen=True)
            class Service(DataClassJsonMixin):
                @dataclass(frozen=True)
                class Customer(CustomerFragment):
                    pass

                id: str
                name: str
                externalId: Optional[str]
                customer: Optional[Customer]

            services: List[Service]

        serviceType: Optional[Node]

    # fmt: off
    @classmethod
    def execute(cls, client: Client, id: str) -> Optional[ServiceTypeServicesQueryData.Node]:
        variables: Dict[str, Any] = {"id": id}
        new_variables = encode_variables(variables, custom_scalars)
        response_text = client.execute(
            gql("".join(set(QUERY))), variable_values=new_variables
        )
        res = cls.ServiceTypeServicesQueryData.from_dict(response_text)
        return res.serviceType

    # fmt: off
    @classmethod
    async def execute_async(cls, client: Client, id: str) -> Optional[ServiceTypeServicesQueryData.Node]:
        variables: Dict[str, Any] = {"id": id}
        new_variables = encode_variables(variables, custom_scalars)
        response_text = await client.execute_async(
            gql("".join(set(QUERY))), variable_values=new_variables
        )
        res = cls.ServiceTypeServicesQueryData.from_dict(response_text)
        return res.serviceType



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import formula

from ..graphql.input.edit_formula_input import EditFormulaInput
from ..graphql.input.add_formula_input import AddFormulaInput
from ..graphql.mutation.add_formula import addFormula
from ..graphql.mutation.edit_formula import editFormula
from ..graphql.mutation.remove_formula import removeFormula
from ..graphql.query.formulas import formulas
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_formula(
    client: SymphonyClient, textformula: str, status: bool,  techFk: str, networkTypeFk: str,  kpiFk: str
) -> formula:
   
    formula_input = AddFormulaInput(textFormula=textformula, 
    status=status, 
    techFk= techFk,
    networkTypeFk= networkTypeFk,
    kpiFk= kpiFk
   
   )
    result = addFormula.execute(client, input=formula_input)
    return formula(textFormula=result.textFormula, 
    id=result.id,  
    status=result.status, 
    techFk=result.techFk,
    networkTypeFk=result.networkTypeFk,
    kpiFk=result.kpiFk
)





